.. include:: ../README.md
   :parser: myst_parser.sphinx_

Table of contents
=================
.. toctree::
   :maxdepth: 2

   Overview <index>
   parameters
   Python API <autoapi/deepmd-gnn/index>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
